# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class ClusterClusterQuotaUsageResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'organization_quota': 'dict[str, int]',
        'organization_quota_usage': 'dict[str, float]',
        'user_quota': 'dict[str, int]',
        'user_quota_usage': 'dict[str, float]'
    }

    attribute_map = {
        'organization_quota': 'organization_quota',
        'organization_quota_usage': 'organization_quota_usage',
        'user_quota': 'user_quota',
        'user_quota_usage': 'user_quota_usage'
    }

    def __init__(self, organization_quota=None, organization_quota_usage=None, user_quota=None, user_quota_usage=None, local_vars_configuration=None):  # noqa: E501
        """ClusterClusterQuotaUsageResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._organization_quota = None
        self._organization_quota_usage = None
        self._user_quota = None
        self._user_quota_usage = None
        self.discriminator = None

        self.organization_quota = organization_quota
        self.organization_quota_usage = organization_quota_usage
        self.user_quota = user_quota
        self.user_quota_usage = user_quota_usage

    @property
    def organization_quota(self):
        """Gets the organization_quota of this ClusterClusterQuotaUsageResponse.  # noqa: E501


        :return: The organization_quota of this ClusterClusterQuotaUsageResponse.  # noqa: E501
        :rtype: dict[str, int]
        """
        return self._organization_quota

    @organization_quota.setter
    def organization_quota(self, organization_quota):
        """Sets the organization_quota of this ClusterClusterQuotaUsageResponse.


        :param organization_quota: The organization_quota of this ClusterClusterQuotaUsageResponse.  # noqa: E501
        :type organization_quota: dict[str, int]
        """
        if self.local_vars_configuration.client_side_validation and organization_quota is None:  # noqa: E501
            raise ValueError("Invalid value for `organization_quota`, must not be `None`")  # noqa: E501

        self._organization_quota = organization_quota

    @property
    def organization_quota_usage(self):
        """Gets the organization_quota_usage of this ClusterClusterQuotaUsageResponse.  # noqa: E501


        :return: The organization_quota_usage of this ClusterClusterQuotaUsageResponse.  # noqa: E501
        :rtype: dict[str, float]
        """
        return self._organization_quota_usage

    @organization_quota_usage.setter
    def organization_quota_usage(self, organization_quota_usage):
        """Sets the organization_quota_usage of this ClusterClusterQuotaUsageResponse.


        :param organization_quota_usage: The organization_quota_usage of this ClusterClusterQuotaUsageResponse.  # noqa: E501
        :type organization_quota_usage: dict[str, float]
        """
        if self.local_vars_configuration.client_side_validation and organization_quota_usage is None:  # noqa: E501
            raise ValueError("Invalid value for `organization_quota_usage`, must not be `None`")  # noqa: E501

        self._organization_quota_usage = organization_quota_usage

    @property
    def user_quota(self):
        """Gets the user_quota of this ClusterClusterQuotaUsageResponse.  # noqa: E501


        :return: The user_quota of this ClusterClusterQuotaUsageResponse.  # noqa: E501
        :rtype: dict[str, int]
        """
        return self._user_quota

    @user_quota.setter
    def user_quota(self, user_quota):
        """Sets the user_quota of this ClusterClusterQuotaUsageResponse.


        :param user_quota: The user_quota of this ClusterClusterQuotaUsageResponse.  # noqa: E501
        :type user_quota: dict[str, int]
        """
        if self.local_vars_configuration.client_side_validation and user_quota is None:  # noqa: E501
            raise ValueError("Invalid value for `user_quota`, must not be `None`")  # noqa: E501

        self._user_quota = user_quota

    @property
    def user_quota_usage(self):
        """Gets the user_quota_usage of this ClusterClusterQuotaUsageResponse.  # noqa: E501


        :return: The user_quota_usage of this ClusterClusterQuotaUsageResponse.  # noqa: E501
        :rtype: dict[str, float]
        """
        return self._user_quota_usage

    @user_quota_usage.setter
    def user_quota_usage(self, user_quota_usage):
        """Sets the user_quota_usage of this ClusterClusterQuotaUsageResponse.


        :param user_quota_usage: The user_quota_usage of this ClusterClusterQuotaUsageResponse.  # noqa: E501
        :type user_quota_usage: dict[str, float]
        """
        if self.local_vars_configuration.client_side_validation and user_quota_usage is None:  # noqa: E501
            raise ValueError("Invalid value for `user_quota_usage`, must not be `None`")  # noqa: E501

        self._user_quota_usage = user_quota_usage

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ClusterClusterQuotaUsageResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ClusterClusterQuotaUsageResponse):
            return True

        return self.to_dict() != other.to_dict()
